setup — mriqc 0.1.0 documentation

# Source code for setup

    #! /usr/bin/env python
    #
    # Copyright (C) 2012-2014 Michael Waskom <mwaskom@stanford.edu>
    import os
    # temporarily redirect config directory to prevent matplotlib importing
    # testing that for writeable directory which results in sandbox error in
    # certain easy_install versions
    os.environ["MPLCONFIGDIR"] = "."

    DESCRIPTION = "Seaborn: statistical data visualization"
    LONG_DESCRIPTION = """\
    Seaborn is a library for making attractive and informative statistical graphics in Python. It is built on top of matplotlib and tightly integrated with the PyData stack, including support for numpy and pandas data structures and statistical routines from scipy and statsmodels.

    Some of the features that seaborn offers are

    - Several built-in themes that improve on the default matplotlib aesthetics
    - Tools for choosing color palettes to make beautiful plots that reveal patterns in your data
    - Functions for visualizing univariate and bivariate distributions or for comparing them between subsets of data
    - Tools that fit and visualize linear regression models for different kinds of independent and dependent variables
    - Functions that visualize matrices of data and use clustering algorithms to discover structure in those matrices
    - A function to plot statistical timeseries data with flexible estimation and representation of uncertainty around the estimate
    - High-level abstractions for structuring grids of plots that let you easily build complex visualizations
    """

    DISTNAME = 'seaborn'
    MAINTAINER = 'Michael Waskom'
    MAINTAINER_EMAIL = 'mwaskom@stanford.edu'
    URL = 'http://stanford.edu/~mwaskom/software/seaborn/'
    LICENSE = 'BSD (3-clause)'
    DOWNLOAD_URL = 'https://github.com/mwaskom/seaborn/'
    VERSION = '0.7.0.dev'

    try:
        from setuptools import setup
        _has_setuptools = True
    except ImportError:
        from distutils.core import setup

    def check_dependencies():
        install_requires = []

        # Just make sure dependencies exist, I haven't rigorously
        # tested what the minimal versions that will work are
        # (help on that would be awesome)
        try:
            import numpy
        except ImportError:
            install_requires.append('numpy')
        try:
            import scipy
        except ImportError:
            install_requires.append('scipy')
        try:
            import matplotlib
        except ImportError:
            install_requires.append('matplotlib')
        try:
            import pandas
        except ImportError:
            install_requires.append('pandas')

        return install_requires

    if __name__ == "__main__":

        install_requires = check_dependencies()

        setup(name=DISTNAME,
            author=MAINTAINER,
            author_email=MAINTAINER_EMAIL,
            maintainer=MAINTAINER,
            maintainer_email=MAINTAINER_EMAIL,
            description=DESCRIPTION,
            long_description=LONG_DESCRIPTION,
            license=LICENSE,
            url=URL,
            version=VERSION,
            download_url=DOWNLOAD_URL,
            install_requires=install_requires,
            packages=['seaborn', 'seaborn.external', 'seaborn.tests'],
            classifiers=[
                         'Intended Audience :: Science/Research',
                         'Programming Language :: Python :: 2.7',
                         'Programming Language :: Python :: 3.3',
                         'Programming Language :: Python :: 3.4',
                         'License :: OSI Approved :: BSD License',
                         'Topic :: Scientific/Engineering :: Visualization',
                         'Topic :: Multimedia :: Graphics',
                         'Operating System :: POSIX',
                         'Operating System :: Unix',
                         'Operating System :: MacOS'],
              )